@@ -4,8 +4,10 @@ from constructor_io import __version__
 from constructor_io.helpers.exception import ConstructorException
 from constructor_io.modules.autocomplete import Autocomplete
 from constructor_io.modules.browse import Browse
+from constructor_io.modules.catalog import Catalog
 from constructor_io.modules.recommendations import Recommendations
 from constructor_io.modules.search import Search
+from constructor_io.modules.tasks import Tasks
 
 
 class ConstructorIO:
@@ -45,6 +47,8 @@ class ConstructorIO:
         self.search = Search(self.__options)
         self.browse = Browse(self.__options)
         self.recommendations = Recommendations(self.__options)
+        self.catalog = Catalog(self.__options)
+        self.tasks = Tasks(self.__options)
 
     def get_options(self):
         '''Get client options'''
