@@ -5,20 +5,21 @@ from urllib.parse import quote, urlencode
 
 import requests as r
 
+from constructor_io.helpers.exception import ConstructorException
 from constructor_io.helpers.utils import (clean_params, create_auth_header,
                                           create_request_headers,
                                           create_shared_query_params,
                                           throw_http_exception_from_response)
 
 
-def create_autocomplete_url(query, parameters, user_parameters, options):
+def _create_autocomplete_url(query, parameters, user_parameters, options):
     # pylint: disable=too-many-branches
     '''Create URL from supplied query (term) and parameters'''
 
     query_params = create_shared_query_params(options, parameters, user_parameters)
 
     if not query or not isinstance(query, str):
-        raise Exception('query is a required parameter of type string')
+        raise ConstructorException('query is a required parameter of type string')
 
     if parameters:
         if parameters.get('num_results'):
@@ -68,7 +69,7 @@ class Autocomplete:
         if not user_parameters:
             user_parameters = {}
 
-        request_url = create_autocomplete_url(query, parameters, user_parameters, self.__options)
+        request_url = _create_autocomplete_url(query, parameters, user_parameters, self.__options)
         requests = self.__options.get('requests') or r
 
         response = requests.get(
@@ -90,4 +91,4 @@ class Autocomplete:
 
             return json
 
-        raise Exception('get_autocomplete_results response data is malformed')
+        raise ConstructorException('get_autocomplete_results response data is malformed')
